exceptiontools.NoteHeadError
============================

.. inheritance-diagram:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
